novas_reference_system

Type Alias novas_reference_system 

pub type novas_reference_system = c_uint;
The basic types of positional coordinate reference systems supported by NOVAS. These determine only how the celestial pole is to be located, but not how velocities are to be referenced. specific pos-vel coordinates are referenced to an ‘astro_frame’, which must specify one of the values defined here.

@sa novas_frame @sa NOVAS_REFERENCE_SYSTEMS