#[repr(C)]pub struct novas_transform {
pub from_system: novas_reference_system,
pub to_system: novas_reference_system,
pub frame: novas_frame,
pub matrix: novas_matrix,
}Expand description
A transformation between two astronomical coordinate systems for the same observer location and time. This allows for more elegant, generic, and efficient coordinate transformations than the low-level NOVAS functions.
The transformation can be (should be) initialized via novas_make_trasform(), or via novas_invert_transform().
@since 1.1
@sa novas_make_transform() @sa novas_invert_transform() @sa NOVAS_TRANSFORM_INIT
Fields
from_system: novas_reference_system< The original coordinate system
to_system: novas_reference_system< The final coordinate system
frame: novas_frame< The observer place and time for which the transform is valid
matrix: novas_matrix< Transformation matrix elements