pub type RefractionModel = Option<unsafe extern "C" fn(jd_tt: f64, loc: *const on_surface, type_: novas_refraction_type, el: f64) -> f64>;Expand description
A function that returns a refraction correction for a given date/time of observation at the given site on earth, and for a given astrometric source elevation
@param jd_tt [day] Terrestrial Time (TT) based Julian data of observation @param loc Pointer to structure defining the observer’s location on earth, and local weather @param type Whether the input elevation is observed or astrometric: REFRACT_OBSERVED (-1) or REFRACT_ASTROMETRIC (0). @param el [deg] Astrometric (unrefracted) source elevation @return [arcsec] Estimated refraction, or NAN if there was an error (it should also set errno to indicate the type of error).
@since 1.1
Aliased Type
pub enum RefractionModel {
None,
Some(unsafe extern "C" fn(f64, *const novas_on_surface, i32, f64) -> f64),
}