pub type cat_entry = novas_cat_entry;Expand description
Basic astrometric data for any sidereal object located outside the solar system.
Note, that despite the slightly expanded catalog name, this has the same memory footprint as the original NOVAS C version, allowing for cross-compatible binary exchange (I/O) of these structures.
@sa CAT_ENTRY_INIT
Aliased Type
#[repr(C)]pub struct cat_entry {
pub starname: [i8; 50],
pub catalog: [i8; 6],
pub starnumber: i64,
pub ra: f64,
pub dec: f64,
pub promora: f64,
pub promodec: f64,
pub parallax: f64,
pub radialvelocity: f64,
}Fields
starname: [i8; 50]< name of celestial object
catalog: [i8; 6]< catalog designator (e.g., HIP)
starnumber: i64< integer identifier assigned to object
ra: f64< [h] ICRS right ascension
dec: f64< [deg] ICRS declination
promora: f64< [mas/yr] ICRS proper motion in right ascension
promodec: f64< [mas/yr] ICRS proper motion in declination
parallax: f64< [mas] parallax
radialvelocity: f64< [km/s] catalog radial velocity (w.r.t. SSB) < To specify radial velocities defined in the Local Standard of Rest (LSR) < you might use novas_set_lsr_vel()