pub type observer = novas_observer;Expand description
Observer location.
@sa make_observer() @sa make_observer_at_geocenter() @sa make_observer_on_earth() @sa make_observer_in_space() @sa make_solar_system_observer() @sa OBSERVER_INIT
Aliased Type
#[repr(C)]pub struct observer {
pub where_: u32,
pub on_surf: novas_on_surface,
pub near_earth: novas_in_space,
}Fields
where_: u32< observer location type
on_surf: novas_on_surfacestructure containing data for an observer’s location on the surface of the Earth (if where = NOVAS_OBSERVER_ON_EARTH)
near_earth: novas_in_spacedata for an observer’s location in orbit (if where = NOVAS_OBSERVER_IN_EARTH_ORBIT) As of v1.1 the same structure may be used to store heliocentric location and motion for any Solar-system observer also (if where = NOVAS_SOLAR_SYSTEM_OBSERVER).